// state.ts
import { ref, reactive } from 'vue';
import { type Sprite, type CellSize, type AnimationState, type NotificationState, type PreviewBorderSettings } from '@/application/types';

// Core state
export const sprites = ref<Sprite[]>([]);
export const canvas = ref<HTMLCanvasElement | null>(null);
export const ctx = ref<CanvasRenderingContext2D | null>(null);
export const cellSize = reactive<CellSize>({ width: 0, height: 0 });
export const columns = ref(4); // Default number of columns

// UI state
export const draggedSprite = ref<Sprite | null>(null);
export const dragOffset = reactive({ x: 0, y: 0 });
export const isShiftPressed = ref(false);
export const isModalOpen = ref(false);
export const isSettingsModalOpen = ref(false);
export const isSpritesModalOpen = ref(false);
export const isHelpModalOpen = ref(false);
export const zoomLevel = ref(1); // Default zoom level (1 = 100%)

// Preview border settings
export const previewBorder = reactive<PreviewBorderSettings>({
  enabled: false,
  color: '#ff0000', // Default red color
  width: 2, // Default width in pixels
});

// Animation state
export const animation = reactive<AnimationState>({
  canvas: null,
  ctx: null,
  currentFrame: 0,
  isPlaying: false,
  frameRate: 10,
  lastFrameTime: 0,
  animationId: null,
  slider: null,
  manualUpdate: false,
});

// Notification state
export const notification = reactive<NotificationState>({
  isVisible: false,
  message: '',
  type: 'success',
});

// Store the current sprite offset for animation playback
// We'll use a Map to store offsets for each frame, so they're preserved when switching frames
export const spriteOffsets = reactive(new Map<number, { x: number; y: number }>());

// Current sprite offset is a reactive object that will be used for the current frame
export const currentSpriteOffset = reactive({ x: 0, y: 0 });
