// composables/useCanvasInitialization.ts
import { ref, nextTick, type Ref } from 'vue';
import { type CellSize, type AnimationState } from '@/application/types';

export function useCanvasInitialization(animation: Ref<AnimationState>, cellSize: Ref<CellSize>) {
  const animCanvas = ref<HTMLCanvasElement | null>(null);

  const initializeCanvas = async (): Promise<boolean> => {
    // Wait for the next tick to ensure the canvas element is rendered
    await nextTick();

    if (!animCanvas.value) {
      console.error('PreviewModal: Animation canvas not found');
      return false;
    }

    try {
      const context = animCanvas.value.getContext('2d');
      if (!context) {
        console.error('PreviewModal: Failed to get 2D context from animation canvas');
        return false;
      }

      animation.value.canvas = animCanvas.value;
      animation.value.ctx = context;
      return true;
    } catch (error) {
      console.error('PreviewModal: Error initializing animation canvas:', error);
      return false;
    }
  };

  const updateCanvasSize = () => {
    if (!animCanvas.value) {
      console.warn('PreviewModal: Cannot update canvas size - canvas not found');
      return;
    }

    if (cellSize.value?.width && cellSize.value?.height) {
      animCanvas.value.width = cellSize.value.width;
      animCanvas.value.height = cellSize.value.height;
    } else {
      console.warn('PreviewModal: Cannot update canvas size - invalid cell dimensions');
    }
  };

  return {
    animCanvas,
    initializeCanvas,
    updateCanvasSize,
  };
}
