import { sprites, canvas, ctx, cellSize, columns, draggedSprite, dragOffset, isShiftPressed, isModalOpen, isSettingsModalOpen, isSpritesModalOpen, isHelpModalOpen, zoomLevel, previewBorder, animation, notification, currentSpriteOffset, spriteOffsets } from '@/application/state';

import { getSpriteOffset, showNotification, createSpriteFromFile, processImageFiles, truncateText } from '@/application/utilities';

import { addSprites, updateCellSize, autoArrangeSprites, highlightSprite, clearAllSprites, applyOffsetsToMainView } from '@/application/spriteOperations';

import { updateCanvasSize, renderSpritesheetPreview, drawGrid, downloadSpritesheet, zoomIn, zoomOut, resetZoom } from '@/application/canvasOperations';

import { startAnimation, stopAnimation, renderAnimationFrame, animationLoop } from '@/application/animationController';

/**
 * Main store function that provides access to all spritesheet functionality
 */
export function useSpritesheetStore() {
  return {
    // State
    sprites,
    canvas,
    ctx,
    cellSize,
    columns,
    draggedSprite,
    dragOffset,
    isShiftPressed,
    isModalOpen,
    isSettingsModalOpen,
    isSpritesModalOpen,
    isHelpModalOpen,
    animation,
    notification,
    zoomLevel,
    previewBorder,
    currentSpriteOffset,
    spriteOffsets,

    // Utils
    getSpriteOffset,
    showNotification,
    createSpriteFromFile,
    processImageFiles,
    truncateText,

    // Sprite operations
    addSprites,
    updateCellSize,
    autoArrangeSprites,
    highlightSprite,
    clearAllSprites: () => clearAllSprites(animation),
    applyOffsetsToMainView: () => applyOffsetsToMainView(currentSpriteOffset),

    // Canvas operations
    updateCanvasSize,
    renderSpritesheetPreview,
    drawGrid,
    downloadSpritesheet,
    zoomIn,
    zoomOut,
    resetZoom,

    // Animation
    startAnimation,
    stopAnimation,
    renderAnimationFrame,
  };
}

// Re-export types
export { type Sprite, type CellSize, type AnimationState } from '@/application/types';
